@@ -7,11 +7,9 @@ from __future__ import (print_function, division, unicode_literals,
 
 import sys
 
-# nipype version information.  An empty version_extra corresponds to a
-# full release.  '.dev' as a version_extra string means this is a development
-# version
+# nipype version information
 # Remove -dev for release
-__version__ = '1.2.1'
+__version__ = '1.2.2'
 
 
 def get_nipype_gitversion():
@@ -63,6 +61,7 @@ CLASSIFIERS = [
     'Programming Language :: Python :: 3.7',
     'Topic :: Scientific/Engineering'
 ]
+PYTHON_REQUIRES = ">= 2.7, != 3.0.*, != 3.1.*, != 3.2.*, != 3.3.*"
 
 description = 'Neuroimaging in Python: Pipelines and Interfaces'
 
