@@ -1,11 +1,13 @@
 # -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft = python sts = 4 ts = 4 sw = 4 et:
-"""AFNI modeling interfaces
+"""
+AFNI modeling interfaces.
 
 Examples
 --------
 See the docstrings of the individual classes for examples.
+
 """
 from __future__ import (print_function, division, unicode_literals,
                         absolute_import)
@@ -17,7 +19,7 @@ from ..base import (CommandLineInputSpec, CommandLine, Directory, TraitedSpec,
 from ...external.due import BibTeX
 
 from .base import (AFNICommandBase, AFNICommand, AFNICommandInputSpec,
-                   AFNICommandOutputSpec)
+                   AFNICommandOutputSpec, Info)
 
 
 class DeconvolveInputSpec(AFNICommandInputSpec):
@@ -307,6 +309,58 @@ class Deconvolve(AFNICommand):
         return outputs
 
 
+    def _gen_fname(self,
+                   basename,
+                   cwd=None,
+                   suffix=None,
+                   change_ext=True,
+                   ext=None):
+        """Generate a filename based on the given parameters.
+
+        The filename will take the form: cwd/basename<suffix><ext>.
+        If change_ext is True, it will use the extentions specified in
+        <instance>intputs.output_type.
+
+        Parameters
+        ----------
+        basename : str
+            Filename to base the new filename on.
+        cwd : str
+            Path to prefix to the new filename. (default is os.getcwd())
+        suffix : str
+            Suffix to add to the `basename`.  (defaults is '' )
+        change_ext : bool
+            Flag to change the filename extension to the FSL output type.
+            (default True)
+
+        Returns
+        -------
+        fname : str
+            New filename based on given parameters.
+
+        """
+        from nipype.utils.filemanip import fname_presuffix
+
+        if basename == '':
+            msg = 'Unable to generate filename for command %s. ' % self.cmd
+            msg += 'basename is not set!'
+            raise ValueError(msg)
+        if cwd is None:
+            cwd = os.getcwd()
+        if ext is None:
+            ext = Info.output_type_to_ext(self.inputs.outputtype)
+        if change_ext:
+            if suffix:
+                suffix = ''.join((suffix, ext))
+            else:
+                suffix = ext
+        if suffix is None:
+            suffix = ''
+        fname = fname_presuffix(
+            basename, suffix=suffix, use_ext=False, newpath=cwd)
+        return fname
+
+
 class RemlfitInputSpec(AFNICommandInputSpec):
     # mandatory files
     in_files = InputMultiPath(
@@ -329,7 +383,7 @@ class RemlfitInputSpec(AFNICommandInputSpec):
         'produces a matrix with a single column of all ones',
         argstr='-polort %d',
         xor=['matrix'])
-    matim = traits.File(
+    matim = File(
         desc='read a standard file as the matrix. You can use only Col as '
         'a name in GLTs with these nonstandard matrix input methods, '
         'since the other names come from the \'matrix\' file. '
