@@ -113,7 +113,7 @@ class BETOutputSpec(TraitedSpec):
 
 
 class BET(FSLCommand):
-    """Use FSL BET command for skull stripping.
+    """FSL BET wrapper for skull stripping
 
     For complete details, see the `BET Documentation.
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/BET/UserGuide>`_
@@ -312,7 +312,7 @@ class FASTOutputSpec(TraitedSpec):
 
 
 class FAST(FSLCommand):
-    """ Use FSL FAST for segmenting and bias correction.
+    """FSL FAST wrapper for segmentation and bias correction
 
     For complete details, see the `FAST Documentation.
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FAST>`_
@@ -635,7 +635,7 @@ class FLIRTOutputSpec(TraitedSpec):
 
 
 class FLIRT(FSLCommand):
-    """Use FSL FLIRT for coregistration.
+    """FSL FLIRT wrapper for coregistration
 
     For complete details, see the `FLIRT Documentation.
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FLIRT>`_
@@ -790,7 +790,7 @@ class MCFLIRTOutputSpec(TraitedSpec):
 
 
 class MCFLIRT(FSLCommand):
-    """Use FSL MCFLIRT to do within-modality motion correction.
+    """FSL MCFLIRT wrapper for within-modality motion correction
 
     For complete details, see the `MCFLIRT Documentation.
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/MCFLIRT>`_
@@ -820,16 +820,16 @@ class MCFLIRT(FSLCommand):
         return super(MCFLIRT, self)._format_arg(name, spec, value)
 
     def _list_outputs(self):
-        cwd = os.getcwd()
         outputs = self._outputs().get()
 
         outputs['out_file'] = self._gen_outfilename()
+        output_dir = os.path.dirname(outputs['out_file'])
 
         if isdefined(self.inputs.stats_imgs) and self.inputs.stats_imgs:
             outputs['variance_img'] = self._gen_fname(
-                outputs['out_file'] + '_variance.ext', cwd=cwd)
+                outputs['out_file'] + '_variance.ext', cwd=output_dir)
             outputs['std_img'] = self._gen_fname(
-                outputs['out_file'] + '_sigma.ext', cwd=cwd)
+                outputs['out_file'] + '_sigma.ext', cwd=output_dir)
 
         # The mean image created if -stats option is specified ('meanvol')
         # is missing the top and bottom slices. Therefore we only expose the
@@ -839,11 +839,11 @@ class MCFLIRT(FSLCommand):
 
         if isdefined(self.inputs.mean_vol) and self.inputs.mean_vol:
             outputs['mean_img'] = self._gen_fname(
-                outputs['out_file'] + '_mean_reg.ext', cwd=cwd)
+                outputs['out_file'] + '_mean_reg.ext', cwd=output_dir)
 
         if isdefined(self.inputs.save_mats) and self.inputs.save_mats:
             _, filename = os.path.split(outputs['out_file'])
-            matpathname = os.path.join(cwd, filename + '.mat')
+            matpathname = os.path.join(output_dir, filename + '.mat')
             _, _, _, timepoints = load(self.inputs.in_file).shape
             outputs['mat_file'] = []
             for t in range(timepoints):
@@ -1106,7 +1106,7 @@ class FNIRTOutputSpec(TraitedSpec):
 
 
 class FNIRT(FSLCommand):
-    """Use FSL FNIRT for non-linear registration.
+    """FSL FNIRT wrapper for non-linear registration
 
     For complete details, see the `FNIRT Documentation.
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FNIRT>`_
@@ -1160,7 +1160,7 @@ class FNIRT(FSLCommand):
                 if suffix.endswith('.txt'):
                     change_ext = False
                 if isdefined(inval):
-                    outputs[key] = inval
+                    outputs[key] = os.path.abspath(inval)
                 else:
                     outputs[key] = self._gen_fname(
                         self.inputs.in_file,
@@ -1305,7 +1305,7 @@ class ApplyWarpOutputSpec(TraitedSpec):
 
 
 class ApplyWarp(FSLCommand):
-    """Use FSL's applywarp to apply the results of a FNIRT registration
+    """FSL's applywarp wrapper to apply the results of a FNIRT registration
 
     Examples
     --------
@@ -1389,7 +1389,7 @@ class SliceTimerOutputSpec(TraitedSpec):
 
 
 class SliceTimer(FSLCommand):
-    """ use FSL slicetimer to perform slice timing correction.
+    """FSL slicetimer wrapper to perform slice timing correction
 
     Examples
     --------
@@ -1476,7 +1476,7 @@ class SUSANOutputSpec(TraitedSpec):
 
 
 class SUSAN(FSLCommand):
-    """ use FSL SUSAN to perform smoothing
+    """FSL SUSAN wrapper to perform smoothing
 
     For complete details, see the `SUSAN Documentation.
     <https://fsl.fmrib.ox.ac.uk/fsl/fslwiki/SUSAN>`_
@@ -1646,7 +1646,8 @@ class FUGUEOutputSpec(TraitedSpec):
 
 
 class FUGUE(FSLCommand):
-    """
+    """FSL FUGUE set of tools for EPI distortion correction
+
     `FUGUE <http://fsl.fmrib.ox.ac.uk/fsl/fslwiki/FUGUE>`_ is, most generally,
     a set of tools for EPI distortion correction.
 
@@ -1869,7 +1870,7 @@ class PRELUDEOutputSpec(TraitedSpec):
 
 
 class PRELUDE(FSLCommand):
-    """Use FSL prelude to do phase unwrapping
+    """FSL prelude wrapper for phase unwrapping
 
     Examples
     --------
@@ -1979,8 +1980,7 @@ class FIRSTOutputSpec(TraitedSpec):
 
 
 class FIRST(FSLCommand):
-    """
-    Use FSL's run_first_all command to segment subcortical volumes
+    """FSL run_first_all wrapper for segmentation of subcortical volumes
 
     http://www.fmrib.ox.ac.uk/fsl/first/index.html
 
