@@ -262,6 +262,68 @@ class Smooth(FSLCommand):
         return super(Smooth, self)._format_arg(name, trait_spec, value)
 
 
+class SliceInputSpec(FSLCommandInputSpec):
+    in_file = File(exists=True, argstr="%s", position=0, mandatory=True,
+                   desc="input filename", copyfile=False)
+    out_base_name = traits.Str(argstr="%s", position=1, desc="outputs prefix")
+
+
+class SliceOutputSpec(TraitedSpec):
+    out_files = OutputMultiPath(File(exists=True))
+
+
+class Slice(FSLCommand):
+    """Use fslslice to split a 3D file into lots of 2D files (along z-axis).
+
+
+    Examples
+    --------
+
+    >>> from nipype.interfaces.fsl import Slice
+    >>> slice = Slice()
+    >>> slice.inputs.in_file = 'functional.nii'
+    >>> slice.inputs.out_base_name = 'sl'
+    >>> slice.cmdline
+    'fslslice functional.nii sl'
+
+
+    """
+
+    _cmd = 'fslslice'
+    input_spec = SliceInputSpec
+    output_spec = SliceOutputSpec
+
+    def _list_outputs(self):
+        """Create a Bunch which contains all possible files generated
+        by running the interface.  Some files are always generated, others
+        depending on which ``inputs`` options are set.
+
+        Returns
+        -------
+
+        outputs : Bunch object
+            Bunch object containing all possible files generated by
+            interface object.
+
+            If None, file was not generated
+            Else, contains path, filename of generated outputfile
+
+        """
+        outputs = self._outputs().get()
+        ext = Info.output_type_to_ext(self.inputs.output_type)
+        suffix = '_slice_*' + ext
+        if isdefined(self.inputs.out_base_name):
+            fname_template = os.path.abspath(
+                self.inputs.out_base_name + suffix)
+        else:
+            fname_template = fname_presuffix(self.inputs.in_file,
+                                             suffix=suffix, use_ext=False)
+
+        outputs['out_files'] = sorted(glob(fname_template))
+
+        return outputs
+
+
 class MergeInputSpec(FSLCommandInputSpec):
     in_files = traits.List(
         File(exists=True), argstr="%s", position=2, mandatory=True)
@@ -489,9 +551,9 @@ class Split(FSLCommand):
         """
         outputs = self._outputs().get()
         ext = Info.output_type_to_ext(self.inputs.output_type)
-        outbase = 'vol*'
+        outbase = 'vol[0-9]*'
         if isdefined(self.inputs.out_base_name):
-            outbase = '%s*' % self.inputs.out_base_name
+            outbase = '%s[0-9]*' % self.inputs.out_base_name
         outputs['out_files'] = sorted(
             glob(os.path.join(os.getcwd(), outbase + ext)))
         return outputs
@@ -500,7 +562,9 @@ class Split(FSLCommand):
 class ImageMathsInputSpec(FSLCommandInputSpec):
     in_file = File(exists=True, argstr="%s", mandatory=True, position=1)
     in_file2 = File(exists=True, argstr="%s", position=3)
-    out_file = File(argstr="%s", position=4, genfile=True, hash_files=False)
+    mask_file = File(exists=True, argstr='-mas %s',
+                     desc='use (following image>0) to mask current image')
+    out_file = File(argstr="%s", position=-2, genfile=True, hash_files=False)
     op_string = traits.Str(
         argstr="%s",
         position=2,
@@ -514,7 +578,7 @@ class ImageMathsInputSpec(FSLCommandInputSpec):
         'double',
         'input',
         argstr="-odt %s",
-        position=5,
+        position=-1,
         desc=("output datatype, one of (char, short, "
               "int, float, double, input)"))
 
@@ -661,18 +725,25 @@ class ImageStatsInputSpec(FSLCommandInputSpec):
         exists=True,
         argstr="%s",
         mandatory=True,
-        position=2,
+        position=3,
         desc='input file to generate stats of')
     op_string = traits.Str(
         argstr="%s",
         mandatory=True,
-        position=3,
+        position=4,
         desc=("string defining the operation, options are "
               "applied in order, e.g. -M -l 10 -M will "
               "report the non-zero mean, apply a threshold "
               "and then report the new nonzero mean"))
     mask_file = File(
         exists=True, argstr="", desc='mask file used for option -k %s')
+    index_mask_file = File(
+        exists=True,
+        argstr="-K %s",
+        position=2,
+        desc="generate seperate n submasks from indexMask, "
+             "for indexvalues 1..n where n is the maximum index "
+             "value in indexMask, and generate statistics for each submask")
 
 
 class ImageStatsOutputSpec(TraitedSpec):
