@@ -21,7 +21,6 @@ import shutil
 import contextlib
 import posixpath
 import simplejson as json
-import numpy as np
 
 from builtins import str, bytes, open
 
@@ -40,8 +39,50 @@ related_filetype_sets = [
 
 PY3 = sys.version_info[0] >= 3
 
-class FileNotFoundError(Exception):
+
+class FileNotFoundError(OSError):  # noqa
+    """Defines the exception for Python 2."""
+
+    def __init__(self, path):
+        """Initialize the exception."""
+        super(FileNotFoundError, self).__init__(
+            2, 'No such file or directory', '%s' % path)
+
+
+USING_PATHLIB2 = False
+try:
+    from pathlib import Path
+except ImportError:
+    from pathlib2 import Path
+    USING_PATHLIB2 = True
+
+try:
+    Path('/invented/file/path').resolve(strict=True)
+except TypeError:
+    def _patch_resolve(self, strict=False):
+        """Add the argument strict to signature in Python>3,<3.6."""
+        resolved = Path().old_resolve() / self
+
+        if strict and not resolved.exists():
+            raise FileNotFoundError(resolved)
+        return resolved
+
+    Path.old_resolve = Path.resolve
+    Path.resolve = _patch_resolve
+except FileNotFoundError:
     pass
+except OSError:
+    def _patch_resolve(self, strict=False):
+        """Raise FileNotFoundError instead of OSError with pathlib2."""
+        try:
+            resolved = self.old_resolve(strict=strict)
+        except OSError:
+            raise FileNotFoundError(self.old_resolve())
+
+        return resolved
+
+    Path.old_resolve = Path.resolve
+    Path.resolve = _patch_resolve
 
 
 def split_filename(fname):
@@ -629,58 +670,55 @@ def load_json(filename):
 
 def loadcrash(infile, *args):
     if infile.endswith('pkl') or infile.endswith('pklz'):
-        return loadpkl(infile, versioning=True)
+        return loadpkl(infile)
     else:
         raise ValueError('Only pickled crashfiles are supported')
 
 
-def loadpkl(infile, versioning=False):
-    """Load a zipped or plain cPickled file
-    """
+def loadpkl(infile):
+    """Load a zipped or plain cPickled file."""
+    infile = Path(infile)
     fmlogger.debug('Loading pkl: %s', infile)
-    if infile.endswith('pklz'):
-        pkl_file = gzip.open(infile, 'rb')
-    else:
-        pkl_file = open(infile, 'rb')
+    pklopen = gzip.open if infile.suffix == '.pklz' else open
+    pkl_metadata = None
 
-    if versioning:
-        pkl_metadata = {}
+    unpkl = None
+    with indirectory(infile.parent):
+        pkl_file = pklopen(infile.name, 'rb')
 
-        # Look if pkl file contains version file
-        try:
+        try:  # Look if pkl file contains version file
             pkl_metadata_line = pkl_file.readline()
             pkl_metadata = json.loads(pkl_metadata_line)
-        except:
+        except (UnicodeDecodeError, json.JSONDecodeError):
             # Could not get version info
             pkl_file.seek(0)
 
-    try:
         try:
             unpkl = pickle.load(pkl_file)
         except UnicodeDecodeError:
+            # Was this pickle created with Python 2.x?
             unpkl = pickle.load(pkl_file, fix_imports=True, encoding='utf-8')
-
-        return unpkl
-
-    # Unpickling problems
-    except Exception as e:
-        if not versioning:
+            fmlogger.info('Successfully loaded pkl in compatibility mode.')
+        # Unpickling problems
+        except Exception as e:
+            if pkl_metadata and 'version' in pkl_metadata:
+                from nipype import __version__ as version
+                if pkl_metadata['version'] != version:
+                    fmlogger.error("""\
+Attempted to open a results file generated by Nipype version %s, \
+with an incompatible Nipype version (%s)""", pkl_metadata['version'], version)
+                    raise e
+            fmlogger.error("""\
+No metadata was found in the pkl file. Make sure you are currently using \
+the same Nipype version from the generated pkl.""")
             raise e
+        finally:
+            pkl_file.close()
 
-        from nipype import __version__ as version
+    if unpkl is None:
+        raise ValueError('Loading %s resulted in None.' % infile)
 
-        if 'version' in pkl_metadata:
-            if pkl_metadata['version'] != version:
-                fmlogger.error('Your Nipype version is: %s',
-                               version)
-                fmlogger.error('Nipype version of the pkl is: %s',
-                               pkl_metadata['version'])
-        else:
-            fmlogger.error('No metadata was found in the pkl file.')
-            fmlogger.error('Make sure that you are using the same Nipype'
-                           'version from the generated pkl.')
-
-        raise e
+    return unpkl
 
 
 def crash2txt(filename, record):
@@ -1000,7 +1038,7 @@ def relpath(path, start=None):
 @contextlib.contextmanager
 def indirectory(path):
     cwd = os.getcwd()
-    os.chdir(path)
+    os.chdir(str(path))
     try:
         yield
     finally:
