@@ -8,13 +8,15 @@ import os
 import time
 import warnings
 
+import mock
 import pytest
 from ...testing import TempFATFS
 from ...utils.filemanip import (
     save_json, load_json, fname_presuffix, fnames_presuffix, hash_rename,
     check_forhash, _parse_mount_table, _cifs_table, on_cifs, copyfile,
-    copyfiles, filename_to_list, list_to_filename, check_depends,
-    split_filename, get_related_files)
+    copyfiles, ensure_list, simplify_list, check_depends,
+    split_filename, get_related_files, indirectory,
+    loadpkl, loadcrash, savepkl, FileNotFoundError, Path)
 
 
 def _ignore_atime(stat):
@@ -24,6 +26,7 @@ def _ignore_atime(stat):
 @pytest.mark.parametrize(
     "filename, split",
     [('foo.nii', ('', 'foo', '.nii')), ('foo.nii.gz', ('', 'foo', '.nii.gz')),
+     ('foo.niml.dset', ('', 'foo', '.niml.dset')),
      ('/usr/local/foo.nii.gz',
       ('/usr/local', 'foo', '.nii.gz')), ('../usr/local/foo.nii',
                                           ('../usr/local', 'foo', '.nii')),
@@ -261,8 +264,8 @@ def test_get_related_files_noninclusive(_temp_analyze_files):
 @pytest.mark.parametrize("filename, expected",
                          [('foo.nii', ['foo.nii']), (['foo.nii'], ['foo.nii']),
                           (('foo', 'bar'), ['foo', 'bar']), (12.34, None)])
-def test_filename_to_list(filename, expected):
-    x = filename_to_list(filename)
+def test_ensure_list(filename, expected):
+    x = ensure_list(filename)
     assert x == expected
 
 
@@ -270,8 +273,8 @@ def test_filename_to_list(filename, expected):
     (['foo.nii'], 'foo.nii'),
     (['foo', 'bar'], ['foo', 'bar']),
 ])
-def test_list_to_filename(list, expected):
-    x = list_to_filename(list)
+def test_simplify_list(list, expected):
+    x = simplify_list(list)
     assert x == expected
 
 
@@ -451,7 +454,16 @@ tmpfs on /proc/timer_list type tmpfs (rw,nosuid,size=65536k,mode=755)
 tmpfs on /proc/sched_debug type tmpfs (rw,nosuid,size=65536k,mode=755)
 tmpfs on /proc/scsi type tmpfs (ro,relatime)
 tmpfs on /sys/firmware type tmpfs (ro,relatime)
-''', 0, [('/data', 'cifs')])
+''', 0, [('/data', 'cifs')]),
+# From @yarikoptic - added blank lines to test for resilience
+(r'''/proc on /proc type proc (rw,relatime)
+sysfs on /sys type sysfs (rw,nosuid,nodev,noexec,relatime)
+tmpfs on /dev/shm type tmpfs (rw,relatime)
+devpts on /dev/pts type devpts (rw,nosuid,noexec,relatime,gid=5,mode=620,ptmxmode=666)
+
+devpts on /dev/ptmx type devpts (rw,nosuid,noexec,relatime,gid=5,mode=620,ptmxmode=666)
+
+''', 0, []),
 )
 
 
@@ -480,3 +492,107 @@ def test_cifs_check():
 
     _cifs_table[:] = []
     _cifs_table.extend(orig_table)
+
+
+def test_indirectory(tmpdir):
+    tmpdir.chdir()
+
+    os.makedirs('subdir1/subdir2')
+    sd1 = os.path.abspath('subdir1')
+    sd2 = os.path.abspath('subdir1/subdir2')
+
+    assert os.getcwd() == tmpdir.strpath
+    with indirectory('/'):
+        assert os.getcwd() == '/'
+    assert os.getcwd() == tmpdir.strpath
+    with indirectory('subdir1'):
+        assert os.getcwd() == sd1
+        with indirectory('subdir2'):
+            assert os.getcwd() == sd2
+            with indirectory('..'):
+                assert os.getcwd() == sd1
+                with indirectory('/'):
+                    assert os.getcwd() == '/'
+                assert os.getcwd() == sd1
+            assert os.getcwd() == sd2
+        assert os.getcwd() == sd1
+    assert os.getcwd() == tmpdir.strpath
+    try:
+        with indirectory('subdir1'):
+            raise ValueError("Erroring out of context")
+    except ValueError:
+        pass
+    assert os.getcwd() == tmpdir.strpath
+
+
+def test_pklization(tmpdir):
+    tmpdir.chdir()
+
+    exc = Exception("There is something wrong here")
+    savepkl('./except.pkz', exc)
+    newexc = loadpkl('./except.pkz')
+
+    assert exc.args == newexc.args
+    assert os.getcwd() == tmpdir.strpath
+
+
+class Pickled:
+
+    def __getstate__(self):
+        return self.__dict__
+
+
+class PickledBreaker:
+
+    def __setstate__(self, d):
+        raise Exception()
+
+
+def test_versioned_pklization(tmpdir):
+    tmpdir.chdir()
+
+    obj = Pickled()
+    savepkl('./pickled.pkz', obj, versioning=True)
+
+    with pytest.raises(Exception):
+        with mock.patch('nipype.utils.tests.test_filemanip.Pickled', PickledBreaker), \
+             mock.patch('nipype.__version__', '0.0.0'):
+
+            loadpkl('./pickled.pkz')
+
+
+def test_unversioned_pklization(tmpdir):
+    tmpdir.chdir()
+
+    obj = Pickled()
+    savepkl('./pickled.pkz', obj)
+
+    with pytest.raises(Exception):
+        with mock.patch('nipype.utils.tests.test_filemanip.Pickled', PickledBreaker):
+            loadpkl('./pickled.pkz')
+
+
+def test_Path_strict_resolve(tmpdir):
+    """Check the monkeypatch to test strict resolution of Path."""
+    tmpdir.chdir()
+
+    # Default strict=False should work out out of the box
+    testfile = Path('somefile.txt')
+    assert '%s/somefile.txt' % tmpdir == '%s' % testfile.resolve()
+
+    # Switching to strict=True must raise FileNotFoundError (also in Python2)
+    with pytest.raises(FileNotFoundError):
+        testfile.resolve(strict=True)
+
+    # If the file is created, it should not raise
+    open('somefile.txt', 'w').close()
+    assert '%s/somefile.txt' % tmpdir == '%s' % testfile.resolve(strict=True)
+
+
+@pytest.mark.parametrize("save_versioning", [True, False])
+def test_pickle(tmp_path, save_versioning):
+    testobj = 'iamateststr'
+    pickle_fname = str(tmp_path / 'testpickle.pklz')
+    savepkl(pickle_fname, testobj, versioning=save_versioning)
+    outobj = loadpkl(pickle_fname)
+    assert outobj == testobj
